LiteXlsx class

Biblioteca minimalista e otimizada para gerar XLSX. Compatível com dart2js.

Constructors

LiteXlsx()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

create(Map<String, dynamic> workbook) Uint8List
Cria o arquivo XLSX compactado retornando os bytes.