LiPdfViewerLabels class

Constructors

LiPdfViewerLabels({String loading = 'Loading PDF...', String emptyState = 'Select a PDF to preview.', String fitWidth = 'Fit width', String rotate = 'Rotate', String download = 'Download', String print = 'Print', String goToPage = 'Go to page', String goToPageTitle = 'Go to page', String moreActions = 'More PDF actions', String mobileActions = 'PDF actions', String fullscreen = 'Fullscreen', String exitFullscreen = 'Exit fullscreen', String enablePan = 'Enable pan mode', String disablePan = 'Disable pan mode', String previousPage = 'Previous page', String nextPage = 'Next page', String page = 'Page', String zoomOut = 'Zoom out', String zoomIn = 'Zoom in', String cancel = 'Cancel', String confirm = 'OK', String errorPrefix = 'Unable to load PDF:', String selectZoomTitle = 'Select zoom', String pageRangeHintPrefix = 'Enter a page between', String pageRangeHintMiddle = 'and'})
const

Properties

cancel String
final
confirm String
final
disablePan String
final
download String
final
emptyState String
final
enablePan String
final
errorPrefix String
final
exitFullscreen String
final
fitWidth String
final
fullscreen String
final
goToPage String
final
goToPageTitle String
final
hashCode int
The hash code for this object.
no setterinherited
loading String
final
mobileActions String
final
moreActions String
final
nextPage String
final
page String
final
pageRangeHintMiddle String
final
pageRangeHintPrefix String
final
previousPage String
final
print String
final
rotate String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
selectZoomTitle String
final
zoomIn String
final
zoomOut String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
pageRangeHint(int totalPages) String
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

english → const LiPdfViewerLabels
portuguese → const LiPdfViewerLabels