LiPdfViewerPageInfo class

Constructors

LiPdfViewerPageInfo({required int pageNumber, required double width, required double height, required int rotation, required double currentScale, required bool isRendered, required bool hasTextLayer, required bool hasAnnotationLayer})
const

Properties

currentScale double
final
hasAnnotationLayer bool
final
hashCode int
The hash code for this object.
no setterinherited
hasTextLayer bool
final
height double
final
isRendered bool
final
pageNumber int
final
rotation int
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
width double
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited