LiQuillTextEditorComponent class

Annotations
  • @Component.new(selector: 'li-quill-text-editor', templateUrl: 'quill_text_editor_component.html', styleUrls: ['quill_text_editor_component.css'], directives: [coreDirectives], providers: [ExistingProvider.forToken(ngValueAccessor, LiQuillTextEditorComponent)], changeDetection: ChangeDetectionStrategy.onPush)

Constructors

LiQuillTextEditorComponent(ChangeDetectorRef _changeDetectorRef)

Properties

containerClass String
getter/setter pair
deltaJsonChange Stream<String>
no setter
disabledToolbarItemIds List<String>?
no getter
editorClass String
getter/setter pair
editorContainer DivElement?
getter/setter pair
enableDestructiveToolbarRebuild bool
getter/setter pair
enableTableButton bool
getter/setter pair
enableTableSupport bool
getter/setter pair
error Stream<String>
no setter
errorMessage String?
getter/setter pair
fontSizeOptions List<LiQuillToolbarOption>?
no getter
hashCode int
The hash code for this object.
no setterinherited
hasToolbarActionsTemplate bool
no setter
headerOptions List<LiQuillToolbarOption>?
no getter
hiddenToolbarItemIds List<String>?
no getter
isReady bool
no setter
labels LiQuillTextEditorLabels
getter/setter pair
leadingToolbarActions List<LiQuillToolbarAction>
getter/setter pair
minHeight String
getter/setter pair
placeholder String
getter/setter pair
projectedToolbarActionsTemplate LiQuillTextEditorToolbarActionsDirective?
getter/setter pair
quillInstance → Quill?
no setter
readOnly bool
getter/setter pair
ready Stream<LiQuillTextEditorComponent>
no setter
resolvedFontSizeOptions List<LiQuillToolbarOption>
getter/setter pair
resolvedHeaderOptions List<LiQuillToolbarOption>
getter/setter pair
resolvedToolbarActionsTemplate → TemplateRef?
no setter
resolvedToolbarItems List<LiQuillToolbarItem>
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
selectionChange Stream<LiQuillTextEditorSelection?>
no setter
tableMenus List<String>
getter/setter pair
templateContext LiQuillTextEditorTemplateContext
latefinal
textChange Stream<String>
no setter
theme String
getter/setter pair
toolbar DivElement?
getter/setter pair
toolbarAction Stream<LiQuillToolbarActionEvent>
no setter
toolbarActions List<LiQuillToolbarAction>
getter/setter pair
toolbarActionsTemplate ↔ TemplateRef?
getter/setter pair
toolbarClass String
getter/setter pair
toolbarItems List<LiQuillToolbarItem>?
no getter
toolbarStructureMounted bool
getter/setter pair
toolbarVisible bool
getter/setter pair
trailingToolbarActions List<LiQuillToolbarAction>
getter/setter pair
updateModelOnBlur bool
getter/setter pair
valueChange Stream<String>
no setter

Methods

blur() → void
clear() → void
commitPendingModelUpdate() → void
focus() → void
format(String name, dynamic value, [String source = 'user']) → void
getDeltaJson() String
getDeltaOps() List<Map<String, dynamic>>
getHtml() String
getPlainText() String
insertTextAtSelection(String text, {String source = 'user'}) → void
isToolbarItemDisabled(LiQuillToolbarItem item) bool
isToolbarItemHidden(LiQuillToolbarItem item) bool
ngAfterChanges() → void
ngAfterViewInit() → void
ngOnDestroy() → void
Executed before the directive is removed from the DOM and destroyed.
ngOnInit() → void
Executed after the first change detection run for a directive.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onDisabledChanged(bool isDisabled) → void
This function is called when the control status changes to or from "DISABLED".
onToolbarActionClick(LiQuillToolbarAction action) → void
registerOnChange(ChangeFunction<String?> fn) → void
Set the function to be called when the control receives a change event.
registerOnTouched(TouchFunction fn) → void
Set the function to be called when the control is touched.
setDeltaJson(String deltaJson) Future<void>
shouldApplyToolbarItemHiddenAttribute(LiQuillToolbarItem item) bool
shouldRenderToolbarItem(LiQuillToolbarItem item) bool
toString() String
A string representation of this object.
inherited
trackByActionId(int index, Object? action) Object?
trackByItemId(int index, Object? item) Object?
writeValue(String? value) → void
Write a new value to the element.

Operators

operator ==(Object other) bool
The equality operator.
inherited