LiPdfViewerToolbarAction class
Constructors
- LiPdfViewerToolbarAction({required String id, required String iconClass, String label = '', String title = '', String buttonClass = '', LiPdfViewerToolbarActionPlacement placement = LiPdfViewerToolbarActionPlacement.trailing, bool showInToolbar = true, bool showInDesktopOverflowMenu = true, bool showInMobileMenu = true, bool disabled = false, bool active = false, LiPdfViewerToolbarActionStringResolver? labelBuilder, LiPdfViewerToolbarActionStringResolver? titleBuilder, LiPdfViewerToolbarActionStringResolver? iconClassBuilder, LiPdfViewerToolbarActionBoolResolver? disabledBuilder, LiPdfViewerToolbarActionBoolResolver? activeBuilder, LiPdfViewerToolbarActionCallback? onPressed})
-
const
Properties
- active → bool
-
final
- activeBuilder → LiPdfViewerToolbarActionBoolResolver?
-
final
-
final
- disabled → bool
-
final
- disabledBuilder → LiPdfViewerToolbarActionBoolResolver?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- iconClass → String
-
final
- iconClassBuilder → LiPdfViewerToolbarActionStringResolver?
-
final
- id → String
-
final
- label → String
-
final
- labelBuilder → LiPdfViewerToolbarActionStringResolver?
-
final
- onPressed → LiPdfViewerToolbarActionCallback?
-
final
- placement → LiPdfViewerToolbarActionPlacement
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- showInDesktopOverflowMenu → bool
-
final
- showInMobileMenu → bool
-
final
- showInToolbar → bool
-
final
- title → String
-
final
- titleBuilder → LiPdfViewerToolbarActionStringResolver?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited