LiQuillTextEditorTemplateContext class
Constructors
Properties
- deltaJson → String
-
no setter
- editor → LiQuillTextEditorComponent
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- htmlValue → String
-
no setter
- isReady → bool
-
no setter
- plainText → String
-
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
blur(
) → void -
clear(
) → void -
focus(
) → void -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
setDeltaJson(
String value) → Future< void> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited